@@ -12,9 +12,6 @@
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-# REVISION
-#   $Id: Image.pm,v 1.21 2006/05/30 17:01:35 abw Exp $
-#
 #============================================================================
 
 package Template::Plugin::Image;
@@ -160,7 +157,7 @@ sub tag {
     my $options = ref $_[0] eq 'HASH' ? shift : { @_ };
 
     my $tag = '<img src="' . $self->name() . '" ' . $self->attr();
- 
+
     # XHTML spec says that the alt attribute is mandatory, so who
     # are we to argue?
 
@@ -168,8 +165,8 @@ sub tag {
         unless defined $options->{ alt };
 
     if (%$options) {
-        while (my ($key, $val) = each %$options) {
-            my $escaped = escape( $val );
+        for my $key (sort keys %$options) {
+            my $escaped = escape( $options->{$key} );
             $tag .= qq[ $key="$escaped"];
         }
     }
@@ -207,18 +204,6 @@ sub AUTOLOAD {
 
 __END__
 
-
-#------------------------------------------------------------------------
-# IMPORTANT NOTE
-#   This documentation is generated automatically from source
-#   templates.  Any changes you make here may be lost.
-# 
-#   The 'docsrc' documentation source bundle is available for download
-#   from http://www.template-toolkit.org/docs.html and contains all
-#   the source templates, XML files, scripts, etc., from which the
-#   documentation for the Template Toolkit is built.
-#------------------------------------------------------------------------
-
 =head1 NAME
 
 Template::Plugin::Image - Plugin access to image sizes
@@ -234,10 +219,10 @@ Template::Plugin::Image - Plugin access to image sizes
 
 =head1 DESCRIPTION
 
-This plugin provides an interface to the Image::Info or Image::Size
+This plugin provides an interface to the L<Image::Info> or L<Image::Size>
 modules for determining the size of image files.
 
-You can specify the plugin name as either 'Image' or 'image'.  The
+You can specify the plugin name as either 'C<Image>' or 'C<image>'.  The
 plugin object created will then have the same name.  The file name of
 the image should be specified as a positional or named argument.
 
@@ -248,7 +233,7 @@ the image should be specified as a positional or named argument.
     [% USE image(name='baz.gif') %]
     [% USE Image name='pong.gif' %]
 
-A "root" parameter can be used to specify the location of the image file:
+A C<root> parameter can be used to specify the location of the image file:
 
     [% USE Image(root='/path/to/root', name='images/home.png') %]
     # image path: /path/to/root/images/home.png
@@ -259,23 +244,23 @@ file name directly:
 
     [% USE Image(file='/path/to/home.png', name='/images/home.png') %]
 
-The "alt" parameter can be used to specify an alternate name for the
-image, for use in constructing an XHTML element (see the tag() method
+The C<alt> parameter can be used to specify an alternate name for the
+image, for use in constructing an XHTML element (see the C<tag()> method
 below).
 
     [% USE Image('home.png', alt="Home") %]
 
-You can also provide an alternate name for an Image plugin object.
+You can also provide an alternate name for an C<Image> plugin object.
 
     [% USE img1 = image 'foo.gif' %]
     [% USE img2 = image 'bar.gif' %]
 
-The 'name' method returns the image file name.
+The C<name> method returns the image file name.
 
     [% img1.name %]     # foo.gif
 
-The 'width' and 'height' methods return the width and height of the
-image, respectively.  The 'size' method returns a reference to a 2
+The C<width> and C<height> methods return the width and height of the
+image, respectively.  The C<size> method returns a reference to a 2
 element list containing the width and height.
 
     [% USE image 'foo.gif' %]
@@ -283,14 +268,14 @@ element list containing the width and height.
     height: [% image.height %]
     size: [% image.size.join(', ') %]
 
-The 'modtime' method returns the ctime of the file in question, suitable
-for use with date.format:
+The C<modtime> method returns the modification time of the file in question,
+suitable for use with the L<Date|Template::Plugin::Date> plugin, for example:
 
     [% USE image 'foo.gif' %]
     [% USE date %]
     [% date.format(image.modtime, "%B, %e %Y") %]
 
-The 'attr' method returns the height and width as HTML/XML attributes.
+The C<attr> method returns the height and width as HTML/XML attributes.
 
     [% USE image 'foo.gif' %]
     [% image.attr %]
@@ -299,7 +284,7 @@ Typical output:
 
     width="60" height="20"
 
-The 'tag' method returns a complete XHTML tag referencing the image.
+The C<tag> method returns a complete XHTML tag referencing the image.
 
     [% USE image 'foo.gif' %]
     [% image.tag %]
@@ -318,18 +303,18 @@ Typical output:
 
     <img src="foo.gif" width="60" height="20" alt="Logo" class="logo" />
 
-Note that the 'alt' attribute is mandatory in a strict XHTML 'img'
+Note that the C<alt> attribute is mandatory in a strict XHTML C<img>
 element (even if it's empty) so it is always added even if you don't
 explicitly provide a value for it.  You can do so as an argument to 
-the 'tag' method, as shown in the previous example, or as an argument
+the C<tag> method, as shown in the previous example, or as an argument
 
     [% USE image('foo.gif', alt='Logo') %]
 
 =head1 CATCHING ERRORS
 
 If the image file cannot be found then the above methods will throw an
-'Image' error.  You can enclose calls to these methods in a
-TRY...CATCH block to catch any potential errors.
+C<Image> error.  You can enclose calls to these methods in a
+C<TRY...CATCH> block to catch any potential errors.
 
     [% TRY;
          image.width;
@@ -340,50 +325,47 @@ TRY...CATCH block to catch any potential errors.
 
 =head1 USING Image::Info
 
-At run time, the plugin tries to load Image::Info in preference to
-Image::Size. If Image::Info is found, then some additional methods are
-available, in addition to 'size', 'width', 'height', 'attr', and 'tag'.
-These additional methods are named after the elements that Image::Info
-retrieves from the image itself; see L<Image::Info> for more details
--- the types of methods available depend on the type of image.
-These additional methods will always include the following:
+At run time, the plugin tries to load L<Image::Info> in preference to
+L<Image::Size>. If L<Image::Info> is found, then some additional methods are
+available, in addition to C<size>, C<width>, C<height>, C<attr>, and C<tag>.
+These additional methods are named after the elements that L<Image::Info>
+retrieves from the image itself. The types of methods available depend on the
+type of image (see L<Image::Info> for more details). These additional methods
+will always include the following:
 
-=over 4
-
-=item file_media_type
+=head2 file_media_type
 
 This is the MIME type that is appropriate for the given file format.
-The corresponding value is a string like: "image/png" or "image/jpeg".
+The corresponding value is a string like: "C<image/png>" or "C<image/jpeg>".
 
-=item file_ext
+=head2 file_ext
 
-The is the suggested file name extention for a file of the given
+The is the suggested file name extension for a file of the given
 file format.  The value is a 3 letter, lowercase string like
-"png", "jpg".
+"C<png>", "C<jpg>".
 
-
-=item color_type
+=head2 color_type
 
 The value is a short string describing what kind of values the pixels
 encode.  The value can be one of the following:
 
-  Gray
-  GrayA
-  RGB
-  RGBA
-  CMYK
-  YCbCr
-  CIELab
+    Gray
+    GrayA
+    RGB
+    RGBA
+    CMYK
+    YCbCr
+    CIELab
 
-These names can also be prefixed by "Indexed-" if the image is
-composed of indexes into a palette.  Of these, only "Indexed-RGB" is
+These names can also be prefixed by "C<Indexed->" if the image is
+composed of indexes into a palette.  Of these, only "C<Indexed-RGB>" is
 likely to occur.
 
 (It is similar to the TIFF field PhotometricInterpretation, but this
-name was found to be too long, so we used the PNG inpired term
+name was found to be too long, so we used the PNG inspired term
 instead.)
 
-=item resolution
+=head2 resolution
 
 The value of this field normally gives the physical size of the image
 on screen or paper. When the unit specifier is missing then this field
@@ -395,68 +377,53 @@ The syntax of this field is:
    <xres> "/" <yres> <unit>
    <xres> "/" <yres>
 
-The E<lt>resE<gt>, E<lt>xresE<gt> and E<lt>yresE<gt> fields are
-numbers.  The E<lt>unitE<gt> is a string like C<dpi>, C<dpm> or
+The C<E<lt>resE<gt>>, C<E<lt>xresE<gt>> and C<E<lt>yresE<gt>> fields are
+numbers.  The C<E<lt>unitE<gt>> is a string like C<dpi>, C<dpm> or
 C<dpcm> (denoting "dots per inch/cm/meter).
 
-=item SamplesPerPixel
+=head2 SamplesPerPixel
 
 This says how many channels there are in the image.  For some image
 formats this number might be higher than the number implied from the
 C<color_type>.
 
-=item BitsPerSample
+=head2 BitsPerSample
 
 This says how many bits are used to encode each of samples.  The value
 is a reference to an array containing numbers. The number of elements
 in the array should be the same as C<SamplesPerPixel>.
 
-=item Comment
+=head2 Comment
 
 Textual comments found in the file.  The value is a reference to an
 array if there are multiple comments found.
 
-=item Interlace
+=head2 Interlace
 
-If the image is interlaced, then this tell which interlace method is
-used.
+If the image is interlaced, then this returns the interlace type.
 
-=item Compression
+=head2 Compression
 
-This tell which compression algorithm is used.
+This returns the name of the compression algorithm is used.
 
-=item Gamma
+=head2 Gamma
 
-A number.
-
-
-=back
+A number indicating the gamma curve of the image (e.g. 2.2)
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
-
-L<http://wardley.org/|http://wardley.org/>
-
-
-
-
-=head1 VERSION
-
-1.21, distributed as part of the
-Template Toolkit version 2.18, released on 09 February 2007.
+Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
-
+Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template::Plugin|Template::Plugin>
+L<Template::Plugin>, L<Image::Info>
 
 =cut
 
