@@ -3,7 +3,6 @@
 # Template::Plugin::Table
 #
 # DESCRIPTION
-#
 #   Plugin to order a linear data set into a virtual 2-dimensional table
 #   from which row and column permutations can be fetched.
 #
@@ -11,14 +10,11 @@
 #   Andy Wardley   <abw@wardley.org>
 #
 # COPYRIGHT
-#   Copyright (C) 2000-2006 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 2000-2007 Andy Wardley.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-# REVISION
-#   $Id: Table.pm,v 2.71 2006/05/30 17:01:36 abw Exp $
-#
 #============================================================================
 
 package Template::Plugin::Table;
@@ -26,6 +22,7 @@ package Template::Plugin::Table;
 use strict;
 use warnings;
 use base 'Template::Plugin';
+use Scalar::Util 'blessed';
 
 our $VERSION = 2.71;
 our $AUTOLOAD;
@@ -39,7 +36,7 @@ our $AUTOLOAD;
 # It calculates the shape of the permutation table based on the ROWS
 # or COLS parameters specified in the $args hash reference.  The
 # OVERLAP parameter may be provided to specify the number of common
-# items that should be shared between subseqent columns.
+# items that should be shared between subsequent columns.
 #------------------------------------------------------------------------
 
 sub new {
@@ -49,13 +46,13 @@ sub new {
     # if the data item is a reference to a Template::Iterator object,
     # or subclass thereof, we call its get_all() method to extract all
     # the data it contains
-    if (UNIVERSAL::isa($data, 'Template::Iterator')) {
+    if (blessed($data) && $data->isa('Template::Iterator')) {
         ($data, $error) = $data->get_all();
         return $class->error("iterator failed to provide data for table: ",
                              $error)
             if $error;
     }
-	
+        
     return $class->error('invalid table data, expecting a list')
         unless ref $data eq 'ARRAY';
 
@@ -228,18 +225,6 @@ sub AUTOLOAD {
 
 __END__
 
-
-#------------------------------------------------------------------------
-# IMPORTANT NOTE
-#   This documentation is generated automatically from source
-#   templates.  Any changes you make here may be lost.
-# 
-#   The 'docsrc' documentation source bundle is available for download
-#   from http://www.template-toolkit.org/docs.html and contains all
-#   the source templates, XML files, scripts, etc., from which the
-#   documentation for the Template Toolkit is built.
-#------------------------------------------------------------------------
-
 =head1 NAME
 
 Template::Plugin::Table - Plugin to present data in a table
@@ -247,50 +232,52 @@ Template::Plugin::Table - Plugin to present data in a table
 =head1 SYNOPSIS
 
     [% USE table(list, rows=n, cols=n, overlap=n, pad=0) %]
-
-    [% FOREACH item = table.row(n) %]
+    
+    [% FOREACH item IN table.row(n) %]
        [% item %]
     [% END %]
-
-    [% FOREACH item = table.col(n) %]
+    
+    [% FOREACH item IN table.col(n) %]
        [% item %]
     [% END %]
-
-    [% FOREACH row = table.rows %]
-       [% FOREACH item = row %]
+    
+    [% FOREACH row IN table.rows %]
+       [% FOREACH item IN row %]
           [% item %]
        [% END %]
     [% END %]
-
-    [% FOREACH col = table.cols %]
+    
+    [% FOREACH col IN table.cols %]
        [% col.first %] - [% col.last %] ([% col.size %] entries)
     [% END %]
 
 =head1 DESCRIPTION
 
-The Table plugin allows you to format a list of data items into a 
-virtual table.  When you create a Table plugin via the USE directive,
+The C<Table> plugin allows you to format a list of data items into a 
+virtual table.  When you create a C<Table> plugin via the C<USE> directive,
 simply pass a list reference as the first parameter and then specify 
 a fixed number of rows or columns.
 
     [% USE Table(list, rows=5) %]
     [% USE table(list, cols=5) %]
 
-The 'Table' plugin name can also be specified in lower case as shown
+The C<Table> plugin name can also be specified in lower case as shown
 in the second example above.  You can also specify an alternative variable
 name for the plugin as per regular Template Toolkit syntax.
 
     [% USE mydata = table(list, rows=5) %]
 
 The plugin then presents a table based view on the data set.  The data
-isn't actually reorganised in any way but is available via the row(),
-col(), rows() and cols() as if formatted into a simple two dimensional
-table of n rows x n columns.  Thus, if our sample 'alphabet' list
-contained the letters 'a' to 'z', the above USE directives would
-create plugins that represented the following views of the alphabet.
+isn't actually reorganised in any way but is available via the C<row()>,
+C<col()>, C<rows()> and C<cols()> as if formatted into a simple two dimensional
+table of C<n> rows x C<n> columns.  
+
+So if we had a sample C<alphabet> list contained the letters 'C<a>' to 'C<z>', 
+the above C<USE> directives would create plugins that represented the following 
+views of the alphabet.
 
     [% USE table(alphabet, ... %]
-
+    
     rows=5                  cols=5
     a  f  k  p  u  z        a  g  m  s  y
     b  g  l  q  v           b  h  n  t  z
@@ -299,14 +286,14 @@ create plugins that represented the following views of the alphabet.
     e  j  o  t  y           e  k  q  w
                             f  l  r  x
 
-We can request a particular row or column using the row() and col() 
+We can request a particular row or column using the C<row()> and C<col()>
 methods.
 
     [% USE table(alphabet, rows=5) %]
     [% FOREACH item = table.row(0) %]
        # [% item %] set to each of [ a f k p u z ] in turn
     [% END %]
-
+    
     [% FOREACH item = table.col(2) %]
        # [% item %] set to each of [ m n o p q r ] in turn
     [% END %]
@@ -314,11 +301,12 @@ methods.
 Data in rows is returned from left to right, columns from top to
 bottom.  The first row/column is 0.  By default, rows or columns that
 contain empty values will be padded with the undefined value to fill
-it to the same size as all other rows or columns.  For example, the
-last row (row 4) in the first example would contain the values [ e j o
-t y undef ]. The Template Toolkit will safely accept these undefined
-values and print a empty string.  You can also use the IF directive to
-test if the value is set.
+it to the same size as all other rows or columns.  
+
+For example, the last row (row 4) in the first example would contain the
+values C<[ e j o t y undef ]>. The Template Toolkit will safely accept these
+undefined values and print a empty string. You can also use the IF directive
+to test if the value is set.
 
    [% FOREACH item = table.row(4) %]
       [% IF item %]
@@ -326,7 +314,7 @@ test if the value is set.
       [% END %]
    [% END %]
 
-You can explicitly disable the 'pad' option when creating the plugin to 
+You can explicitly disable the C<pad> option when creating the plugin to 
 returned shortened rows/columns where the data is empty.
 
    [% USE table(alphabet, cols=5, pad=0) %]
@@ -334,12 +322,12 @@ returned shortened rows/columns where the data is empty.
       # [% item %] set to each of 'y z'
    [% END %]
 
-The rows() method returns all rows/columns in the table as a reference
-to a list of rows (themselves list references).  The row() methods
-when called without any arguments calls rows() to return all rows in
+The C<rows()> method returns all rows/columns in the table as a reference
+to a list of rows (themselves list references).  The C<row()> methods
+when called without any arguments calls C<rows()> to return all rows in
 the table.
 
-Ditto for cols() and col().
+Ditto for C<cols()> and C<col()>.
 
     [% USE table(alphabet, cols=5) %]
     [% FOREACH row = table.rows %]
@@ -348,9 +336,9 @@ Ditto for cols() and col().
        [% END %]
     [% END %]
 
-The Template Toolkit provides the first(), last() and size() methods
-that can be called on list references to return the first/last entry
-or the number of entried.  The following example shows how we might 
+The Template Toolkit provides the C<first>, C<last> and C<size> virtual
+methods that can be called on list references to return the first/last entry
+or the number of entries in a list. The following example shows how we might
 use this to provide an alphabetical index split into 3 even parts.
 
     [% USE table(alphabet, cols=3, pad=0) %]
@@ -364,7 +352,7 @@ This produces the following output:
     [ j - r (9 letters) ]
     [ s - z (8 letters) ]
 
-We can also use the general purpose join() list method which joins 
+We can also use the general purpose C<join> virtual method which joins 
 the items of the list using the connecting string specified.
 
     [% USE table(alphabet, cols=5) %]
@@ -374,7 +362,7 @@ the items of the list using the connecting string specified.
 
 Data in the table is ordered downwards rather than across but can easily
 be transformed on output.  For example, to format our data in 5 columns
-with data ordered across rather than down, we specify 'rows=5' to order
+with data ordered across rather than down, we specify C<rows=5> to order
 the data as such:
 
     a  f  .  .
@@ -400,25 +388,28 @@ Example code to do so would be much like the following:
       [% END %]
     [% END %]
 
+Output:
+
     a  b  c
     d  e  f
     g  h  i
     j  .  .
     .
 
-In addition to a list reference, the Table plugin constructor may be 
-passed a reference to a Template::Iterator object or subclass thereof.
-The get_all() method is first called on the iterator to return all 
-remaining items.  These are then available via the usual Table interface.
+In addition to a list reference, the C<Table> plugin constructor may be passed
+a reference to a L<Template::Iterator> object or subclass thereof. The
+L<Template::Iterator> L<get_all()|Template::Iterator#get_all()> method is
+first called on the iterator to return all remaining items. These are then
+available via the usual Table interface.
 
     [% USE DBI(dsn,user,pass) -%]
-
+    
     # query() returns an iterator
     [% results = DBI.query('SELECT * FROM alphabet ORDER BY letter') %]
-    
+
     # pass into Table plugin
     [% USE table(results, rows=8 overlap=1 pad=0) -%]
-
+    
     [% FOREACH row = table.cols -%]
        [% row.first.letter %] - [% row.last.letter %]:
           [% row.join(', ') %]
@@ -426,29 +417,18 @@ remaining items.  These are then available via the usual Table interface.
 
 =head1 AUTHOR
 
-Andy Wardley E<lt>abw@wardley.orgE<gt>
-
-L<http://wardley.org/|http://wardley.org/>
-
-
-
-
-=head1 VERSION
-
-2.71, distributed as part of the
-Template Toolkit version 2.18, released on 09 February 2007.
+Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-  Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
-
+Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template::Plugin|Template::Plugin>
+L<Template::Plugin>
 
 =cut
 
