@@ -26,6 +26,9 @@ use base 'Template::Base';
 use Template::Config;
 use Template::Exception;
 use Template::Constants;
+use Scalar::Util 'blessed';
+
+use constant EXCEPTION => 'Template::Exception';
 
 our $VERSION = 2.80;
 our $DEBUG   = 0 unless defined $DEBUG;
@@ -198,7 +201,7 @@ sub _recover {
     # point... unless a module like CGI::Carp messes around with the 
     # DIE handler. 
     return undef
-        unless UNIVERSAL::isa($$error, 'Template::Exception');
+        unless blessed($$error) && $$error->isa(EXCEPTION);
 
     # a 'stop' exception is thrown by [% STOP %] - we return the output
     # buffer stored in the exception object
@@ -511,7 +514,7 @@ for all uncaught exceptions.
         ERROR => 'error.html'
     });
 
-If the L<ERROR/ERRORS|Template::Manual::Config#ERROR> item is a hash reference
+If the L<ERROR or ERRORS|Template::Manual::Config#ERROR> item is a hash reference
 the keys are assumed to be exception types and the relevant template for a
 given exception will be selected. A C<default> template may be provided for
 the general case.
